@@ -226,10 +226,33 @@ request_domain_info (GTask *task,
                      LDAP *ldap)
 {
 	const char *attrs[] = { "info", "associatedDomain", NULL };
+	int ret;
+	int ldap_opt_val;
 
 	clo->request = NULL;
 	clo->result = result_domain_info;
 
+	/* Trying to setup a TLS tunnel in the case the IPA server requires an
+	 * encrypted connected. Trying without in case of an error. Since we
+	 * most probably do not have the IPA CA certificate we will not check
+	 * the server certificate. */
+	ldap_opt_val = LDAP_OPT_X_TLS_NEVER;
+	ret = ldap_set_option (ldap, LDAP_OPT_X_TLS_REQUIRE_CERT, &ldap_opt_val);
+	if (ret != LDAP_OPT_SUCCESS) {
+		g_debug ("Failed to disable certificate checking, trying without");
+	}
+
+	ldap_opt_val = 0;
+	ret = ldap_set_option (ldap, LDAP_OPT_X_TLS_NEWCTX, &ldap_opt_val);
+	if (ret != LDAP_OPT_SUCCESS) {
+		g_debug ("Failed to refresh LDAP context for TLS, trying without");
+	}
+
+	ret = ldap_start_tls_s (ldap, NULL, NULL);
+	if (ret != LDAP_SUCCESS) {
+		g_debug ("Failed to setup TLS tunnel, trying without");
+	}
+
 	return search_ldap (task, clo, ldap, clo->default_naming_context,
 	                    LDAP_SCOPE_BASE, NULL, attrs);
 }
@@ -429,6 +452,7 @@ on_ldap_io (LDAP *ldap,
 void
 realm_disco_rootdse_async (GSocketAddress *address,
                            const gchar *explicit_server,
+                           gboolean use_ldaps,
                            GDBusMethodInvocation *invocation,
                            GCancellable *cancellable,
                            GAsyncReadyCallback callback,
@@ -450,7 +474,13 @@ realm_disco_rootdse_async (GSocketAddress *address,
 	g_task_set_task_data (task, clo, closure_free);
 
 	clo->source = realm_ldap_connect_anonymous (address, G_SOCKET_PROTOCOL_TCP,
-	                                            cancellable);
+	                                            use_ldaps, cancellable);
+	if (clo->source == NULL) {
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_NOT_CONNECTED,
+		                         _("Failed to setup LDAP connection"));
+		g_object_unref (task);
+		return;
+	}
 	g_source_set_callback (clo->source, (GSourceFunc)on_ldap_io,
 	                       g_object_ref (task), g_object_unref);
 	g_source_attach (clo->source, g_task_get_context (task));
