@@ -21,6 +21,7 @@
 #include "realm-disco.h"
 #include "realm-errors.h"
 #include "realm-kerberos.h"
+#include "realm-kerberos-config.h"
 #include "realm-kerberos-membership.h"
 #include "realm-options.h"
 #include "realm-packages.h"
@@ -180,7 +181,6 @@ on_join_do_winbind (GObject *source,
 	GTask *task = G_TASK (user_data);
 	EnrollClosure *enroll = g_task_get_task_data (task);
 	RealmSamba *self = g_task_get_source_object (task);
-	GHashTable *settings = NULL;
 	GError *error = NULL;
 	const gchar *name;
 	const gchar *computer_name;
@@ -201,10 +201,26 @@ on_join_do_winbind (GObject *source,
 		                         "template shell", realm_settings_string ("users", "default-shell"),
 		                         "netbios name", computer_name,
 		                         "password server", enroll->disco->explicit_server,
-		                         "kerberos method", "system keytab",
+		                         "kerberos method", "secrets and keytab",
 		                         NULL);
 	}
 
+	if (error == NULL && enroll->disco->dns_fqdn != NULL) {
+		realm_ini_config_change (self->config, REALM_SAMBA_CONFIG_GLOBAL, &error,
+		                         "additional dns hostnames", enroll->disco->dns_fqdn,
+		                         NULL);
+	}
+
+	if (error == NULL) {
+		configure_krb5_conf_for_domain (enroll->disco->kerberos_realm, &error);
+		if (error != NULL) {
+			realm_diagnostics_error (enroll->invocation, error,
+			                         "Failed to update Kerberos "
+			                         "configuration, not fatal, "
+			                         "please check manually");
+			g_clear_error (&error);
+		}
+	}
 
 	if (error == NULL) {
 		name = realm_kerberos_get_name (REALM_KERBEROS (self));
@@ -215,8 +231,6 @@ on_join_do_winbind (GObject *source,
 		g_task_return_error (task, error);
 	}
 
-	if (settings)
-		g_hash_table_unref (settings);
 	g_object_unref (task);
 }
 
@@ -243,7 +257,8 @@ on_install_do_join (GObject *source,
 }
 
 static gboolean
-validate_membership_options (GVariant *options,
+validate_membership_options (EnrollClosure *enroll,
+                             GVariant *options,
                              GError **error)
 {
 	const gchar *software;
@@ -257,6 +272,12 @@ validate_membership_options (GVariant *options,
 		}
 	}
 
+	if (realm_option_use_ldaps (options)) {
+		realm_diagnostics_info (enroll->invocation,
+		                        "Membership software %s does "
+		                        "not support ldaps, trying without.",
+		                        software);
+	}
 	return TRUE;
 }
 
@@ -289,7 +310,7 @@ realm_samba_join_async (RealmKerberosMembership *membership,
 		g_task_return_new_error (task, REALM_ERROR, REALM_ERROR_ALREADY_CONFIGURED,
 		                         _("Already joined to a domain"));
 
-	} else if (!validate_membership_options (options, &error)) {
+	} else if (!validate_membership_options (enroll, options, &error)) {
 		g_task_return_error (task, error);
 
 	} else {
@@ -367,6 +388,7 @@ leave_deconfigure_begin (RealmSamba *self,
 	if (!realm_ini_config_change (self->config, REALM_SAMBA_CONFIG_GLOBAL, &error,
 	                              "workgroup", NULL,
 	                              "realm", NULL,
+	                              "additional dns hostnames", NULL,
 	                              "security", "user",
 	                              NULL)) {
 		g_task_return_error (task, error);
