@@ -19,6 +19,7 @@
 #include "realm-dbus-constants.h"
 #include "realm-diagnostics.h"
 #include "realm-errors.h"
+#include "realm-kerberos-config.h"
 #include "realm-kerberos-membership.h"
 #include "realm-options.h"
 #include "realm-packages.h"
@@ -97,6 +98,7 @@ typedef struct {
 	GVariant *options;
 	RealmDisco *disco;
 	gboolean use_adcli;
+	gboolean use_ldaps;
 	const gchar **packages;
 } JoinClosure;
 
@@ -160,6 +162,7 @@ configure_sssd_for_domain (RealmIniConfig *config,
                            gboolean use_adcli,
                            GError **error)
 {
+	const gchar *services[] = { "nss", "pam", NULL };
 	GString *realmd_tags;
 	const gchar *access_provider;
 	const gchar *shell;
@@ -171,7 +174,7 @@ configure_sssd_for_domain (RealmIniConfig *config,
 	gchar *home;
 
 	home = realm_sssd_build_default_home (realm_settings_string ("users", "default-home"));
-	qualify = realm_options_qualify_names (disco->domain_name);
+	qualify = realm_options_qualify_names (disco->domain_name, TRUE);
 	shell = realm_settings_string ("users", "default-shell");
 	explicit_computer_name = realm_options_computer_name (options, disco->domain_name);
 	realmd_tags = g_string_new ("");
@@ -206,6 +209,9 @@ configure_sssd_for_domain (RealmIniConfig *config,
 	                                    "ldap_sasl_authid", authid,
 	                                    NULL);
 
+	if (ret)
+		ret = realm_ini_config_change_list (config, "sssd", "services", ", ", services, NULL, error);
+
 	g_free (authid);
 	g_string_free (realmd_tags, TRUE);
 
@@ -252,6 +258,17 @@ on_join_do_sssd (GObject *source,
 		                           join->options, join->use_adcli, &error);
 	}
 
+	if (error == NULL) {
+		configure_krb5_conf_for_domain (join->disco->kerberos_realm, &error);
+		if (error != NULL) {
+			realm_diagnostics_error (join->invocation, error,
+			                         "Failed to update Kerberos "
+			                         "configuration, not fatal, "
+			                         "please check manually");
+			g_clear_error (&error);
+		}
+	}
+
 	if (error == NULL) {
 		realm_service_enable_and_restart ("sssd", join->invocation,
 		                                  on_sssd_enable_nss, g_object_ref (task));
@@ -278,6 +295,7 @@ on_install_do_join (GObject *source,
 			realm_adcli_enroll_join_async (join->disco,
 			                               join->cred,
 			                               join->options,
+			                               join->use_ldaps,
 			                               join->invocation,
 			                               on_join_do_sssd,
 			                               g_object_ref (task));
@@ -362,6 +380,19 @@ parse_join_options (JoinClosure *join,
 
 	g_assert (software != NULL);
 
+	/*
+	 * Check if ldaps should be used and if membership software supports
+	 * it.
+	 */
+	join->use_ldaps = realm_option_use_ldaps (options);
+	if (join->use_ldaps &&
+	           g_str_equal (software, REALM_DBUS_IDENTIFIER_SAMBA)) {
+		realm_diagnostics_info (join->invocation,
+		                        "Membership software %s does "
+		                        "not support ldaps, trying "
+		                        "without.", software);
+	}
+
 	if (g_str_equal (software, REALM_DBUS_IDENTIFIER_ADCLI)) {
 		join->use_adcli = TRUE;
 		join->packages = ADCLI_PACKAGES;
@@ -507,6 +538,7 @@ realm_sssd_ad_leave_async (RealmKerberosMembership *membership,
 	GTask *task;
 	LeaveClosure *leave;
 	gchar *tags;
+	gboolean use_ldaps = FALSE;
 
 	task = g_task_new (self, NULL, callback, user_data);
 
@@ -535,10 +567,19 @@ realm_sssd_ad_leave_async (RealmKerberosMembership *membership,
 		leave->invocation = g_object_ref (invocation);
 		leave->use_adcli = strstr (tags ? tags : "", "joined-with-adcli") ? TRUE : FALSE;
 		g_task_set_task_data (task, leave, leave_closure_free);
+
+		use_ldaps = realm_option_use_ldaps (options);
 		if (leave->use_adcli) {
-			realm_adcli_enroll_delete_async (disco, cred, options, invocation,
+			realm_adcli_enroll_delete_async (disco, cred, options,
+			                                 use_ldaps,  invocation,
 			                                 on_leave_do_deconfigure, g_object_ref (task));
 		} else {
+			if (use_ldaps) {
+				realm_diagnostics_info (leave->invocation,
+				                        "Membership software does "
+				                        "not support ldaps, trying "
+				                        "without.");
+			}
 			realm_samba_enroll_leave_async (disco, cred, options, invocation,
 			                                on_leave_do_deconfigure, g_object_ref (task));
 		}
