@@ -179,6 +179,7 @@ typedef struct {
 	gchar *user_principal;
 	gboolean automatic_id_mapping_set;
 	gboolean automatic_id_mapping;
+	gboolean use_ldaps;
 } RealmJoinArgs;
 
 static void
@@ -218,7 +219,7 @@ perform_join (RealmClient *client,
 	GList *realms;
 	gint ret;
 
-	realms = realm_client_discover (client, string, args->client_software,
+	realms = realm_client_discover (client, string, args->use_ldaps, args->client_software,
 	                                args->server_software, args->membership_software,
 	                                REALM_DBUS_KERBEROS_MEMBERSHIP_INTERFACE,
 	                                &had_mismatched, &error);
@@ -247,6 +248,7 @@ perform_join (RealmClient *client,
 	                               REALM_DBUS_OPTION_OS_VERSION, args->os_version,
 	                               REALM_DBUS_OPTION_MEMBERSHIP_SOFTWARE, args->membership_software,
 	                               REALM_DBUS_OPTION_USER_PRINCIPAL, args->user_principal,
+	                               REALM_DBUS_OPTION_USE_LDAPS, args->use_ldaps ? "True" : "False",
 	                               args->automatic_id_mapping_set ?
 	                                   REALM_DBUS_OPTION_AUTOMATIC_ID_MAPPING : NULL,
 	                                   args->automatic_id_mapping,
@@ -286,36 +288,38 @@ realm_join (RealmClient *client,
 	gint ret = 0;
 
 	GOptionEntry option_entries[] = {
-		{ "user", 'U', 0, G_OPTION_ARG_STRING, &args.user,
-		  N_("User name to use for enrollment"), NULL },
-		{ "computer-ou", 0, 0, G_OPTION_ARG_STRING, &args.computer_ou,
-		  N_("Computer OU DN to join"), NULL },
-		{ "computer-name", 0, 0, G_OPTION_ARG_STRING, &args.computer_name,
-			N_("Use specific computer name instead of hostname"), NULL },
-		{ "os-name", 0, 0, G_OPTION_ARG_STRING, &args.os_name,
-			N_("Use specific operation system name"), NULL },
-		{ "os-version", 0, 0, G_OPTION_ARG_STRING, &args.os_version,
-			N_("Use specific operation system version"), NULL },
+		{ "automatic-id-mapping", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK,
+		  realm_join_arg_id_mapping, N_("Turn off automatic id mapping"), "no" },
 		{ "client-software", 0, 0, G_OPTION_ARG_STRING, &args.client_software,
 		  N_("Use specific client software"), NULL },
-		{ "server-software", 0, 0, G_OPTION_ARG_STRING, &args.server_software,
-		  N_("Use specific server software"), NULL },
+		{ "computer-name", 0, 0, G_OPTION_ARG_STRING, &args.computer_name,
+                  N_("Use specific computer name instead of hostname"), NULL },
+		{ "computer-ou", 0, 0, G_OPTION_ARG_STRING, &args.computer_ou,
+		  N_("Computer OU DN to join"), NULL },
 		{ "membership-software", 0, 0, G_OPTION_ARG_STRING, &args.membership_software,
 		  N_("Use specific membership software"), NULL },
 		{ "no-password", 0, 0, G_OPTION_ARG_NONE, &args.no_password,
 		  N_("Join automatically without a password"), NULL },
 		{ "one-time-password", 0, 0, G_OPTION_ARG_STRING, &args.one_time_password,
 		  N_("Join using a preset one time password"), NULL },
-		{ "automatic-id-mapping", 0, G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_CALLBACK,
-		  realm_join_arg_id_mapping, N_("Turn off automatic id mapping"), "no" },
+		{ "os-name", 0, 0, G_OPTION_ARG_STRING, &args.os_name,
+                  N_("Use specific operation system name"), NULL },
+		{ "os-version", 0, 0, G_OPTION_ARG_STRING, &args.os_version,
+                  N_("Use specific operation system version"), NULL },
+		{ "server-software", 0, 0, G_OPTION_ARG_STRING, &args.server_software,
+		  N_("Use specific server software"), NULL },
+		{ "user", 'U', 0, G_OPTION_ARG_STRING, &args.user,
+		  N_("User name to use for enrollment"), NULL },
 		{ "user-principal", 0, 0, G_OPTION_ARG_STRING, &args.user_principal,
 		  N_("Set the user principal for the computer account"), NULL },
+		{ "use-ldaps", 0, 0, G_OPTION_ARG_NONE, &args.use_ldaps,
+		  N_("Use ldaps to connect to LDAP"), NULL },
 		{ NULL, }
 	};
 
 	memset (&args, 0, sizeof (args));
 
-	context = g_option_context_new ("realm");
+	context = g_option_context_new ("join REALM");
 	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 
 	group = g_option_group_new (NULL, NULL, NULL, &args, realm_join_args_clear);
